==> gatsby-sports-theme-1.0.14.tgz: package/src/components/atoms/cards/comparison-table/table/index.js <==
/* eslint-disable react/forbid-prop-types */
/* eslint-disable import/no-extraneous-dependencies */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/anchor-is-valid */
import React from 'react';
import PropTypes from 'prop-types';
import { imagePrettyUrl } from 'gatsby-core-theme/src/helpers/getters';
import LazyImg from 'gatsby-core-theme/src/hooks/lazy-image';
import OperatorCta from 'gatsby-core-theme/src/components/atoms/button/operator-cta';
import StarRating from 'gatsby-core-theme/src/components/molecules/star-rating/one-star';
import ReviewLink from 'gatsby-core-theme/src/components/atoms/review-link';
import Link from 'gatsby-core-theme/src/hooks/link';
import Bonus from 'gatsby-core-theme/src/components/molecules/bonus-box/template-one';
import GatsbyImg from 'gatsby-core-theme/src/hooks/gatsby-img';

import LazyImage from '~hooks/lazy-image';
import verify from '../../../../../images/verify.svg';
import styles from './table.module.scss';

const listHeadings = [
  {
    id: 1,
    defaultValue: 'Casino name',
    key: 'casino_name',
  },
  {
    id: 2,
    defaultValue: 'Rating',
    key: 'rating',
  },
  {
    id: 3,
    defaultValue: 'Bonus',
    key: 'bonus',
    // customComponent: ({operator}) => ( <td>{operator.title}</td> ), This is an example
  },
  {
    id: 4,
    defaultValue: 'Top Features',
    key: 'top_features',
  },
  {
    id: 5,
    defaultValue: 'Banking',
    key: 'banking',
  },
  {
    id: 6,
    defaultValue: 'Payment Methods',
    key: 'payment_methods',
  },

  {
    id: 7,
    defaultValue: 'Currencies',
    key: 'currencies',
  },
  {
    id: 8,
    defaultValue: 'Licenses',
    key: 'licenses',
  },
  {
    id: 9,
    defaultValue: 'Cta',
    key: 'cta',
  },
];
export default function ComparisonTable({
  items,
  tabelInfo = listHeadings,
  ctaKey = 'play_now',
  type,
  tempate,
}) {
  const cell = (heading, item, key, index) => {
    const rowData = tabelInfo.find((m) => m.key === heading);
    if (rowData && rowData.customComponent) {
      const CustomComponent = rowData.customComponent;
      return <CustomComponent key={key} operator={item} />;
    }
    const imageObject =
      item?.relation?.standardised_logo_url_object || item?.relation?.logo_url_object;
    const itemName = item?.relation?.name;

    switch (heading) {
      case 'casino_name':
        return (
          <td key={key} className={styles.casinoName}>
            {imageObject?.filename ? (
              <LazyImg
                src={imagePrettyUrl(imageObject?.filename, 64, 64)}
                height={64}
                width={64}
                alt={itemName}
              />
            ) : (
              <GatsbyImg
                filename="default-operator.png"
                alt={itemName}
                width="9rem"
                height="9rem"
              />
            )}

            <span>{itemName}</span>
            {type === 'operator' && index === 0 ? null : (
              <ReviewLink
                template={tempate}
                {...(item?.relation?.name
                  ? { operatorName: item?.relation?.name }
                  : { pageName: item.title })}
                reviewPath={item.path}
              />
            )}
          </td>
        );
      case 'rating':
        return (
          <td key={key} className={styles.raiting}>
            <StarRating numOfStars={5} rating={item?.relation?.rating} />
            {item?.author && (
              <div>
                <LazyImage
                  alt={item?.author?.image_alt}
                  src={imagePrettyUrl(item?.author?.image, 30, 30)}
                  width={30}
                  height={30}
                />
                <LazyImage src={verify} alt="verify" width={10} height={10} />
              </div>
            )}
          </td>
        );
      case 'bonus':
        return (
          <td key={key} className={styles.bonus}>
            <Bonus module="comparison_table" tracker="main" item={item?.relation} />
          </td>
        );
      case 'top_features':
        return (
          <td key={key} className={styles.topFeatures}>
            {item?.relation?.selling_points &&
              item?.relation?.selling_points.map((sellingPoint) => (
                <span key={sellingPoint}>
                  <svg
                    width="24"
                    height="24"
                    viewBox="0 0 24 24"
                    fill="none"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path
                      d="M18.7 7.1999C18.3 6.7999 17.7 6.7999 17.3 7.1999L9.8 14.6999L6.7 11.5999C6.3 11.1999 5.7 11.1999 5.3 11.5999C4.9 11.9999 4.9 12.5999 5.3 12.9999L9.1 16.7999C9.3 16.9999 9.5 17.0999 9.8 17.0999C10.1 17.0999 10.3 16.9999 10.5 16.7999L18.7 8.5999C19.1 8.1999 19.1 7.5999 18.7 7.1999Z"
                      fill="#FFDB20"
                    />
                  </svg>

                  {sellingPoint}
                </span>
              ))}
          </td>
        );
      case 'payment_methods':
        return (
          <td key={key} className={styles.paymentMethods}>
            <div key={key}>
              {item?.relation?.bonus?.deposit_methods &&
                // eslint-disable-next-line array-callback-return
                item?.relation?.bonus?.deposit_methods?.slice(0, 3)?.map((deposit) => {
                  const logo =
                    deposit?.standardised_logo_filename_object?.filename ||
                    deposit?.standardised_logo_filename ||
                    deposit?.logo_filename;
                  if (!logo) return;
                  return (
                    <Link to={deposit?.path}>
                      <LazyImg
                        key={`${key}-${deposit.name}`}
                        src={imagePrettyUrl(logo, 44, 29)}
                        // width={44}
                        // height={29}
                        alt={deposit.name}
                      />
                    </Link>
                  );
                })}
            </div>
            {item?.relation?.bonus?.deposit_methods &&
              item?.relation?.bonus?.deposit_methods.length > 3 && (
                <span>{item?.relation?.bonus?.deposit_methods.length}</span>
              )}
          </td>
        );
      case 'banking':
        return (
          <td key={key} className={styles.banking}>
            {item?.relation?.bonus?.min_deposit && <span>{item.relation.bonus.min_deposit}</span>}
          </td>
        );
      case 'currencies':
        return (
          <td key={key} className={styles.currencies}>
            {item?.relation?.bonus?.currencies &&
              // eslint-disable-next-line no-shadow
              item?.relation?.bonus?.currencies.slice(0, 6).map((currencies, index, array) => (
                // eslint-disable-next-line react/no-array-index-key
                <span key={`${key}-${currencies.iso_code}`}>
                  {currencies.iso_code}
                  {index < array.length - 1 ? ', ' : ' '}
                </span>
              ))}
          </td>
        );
      case 'licenses':
        return (
          <td key={key} className={styles.licenses}>
            {item?.relation?.bonus?.license_objects &&
              item?.relation?.bonus?.license_objects.slice(0, 3).map((license) => {
                if (license?.logo_filename) {
                  return (
                    <LazyImg
                      key={license.name}
                      src={imagePrettyUrl(license?.logo_filename, 72, 72)}
                      height={32}
                      width={72}
                      alt={license.name}
                    />
                  );
                }
                return <></>;
              })}
          </td>
        );
      case 'cta':
        return (
          <td key={key} className={styles.cta}>
            {item?.relation?.status !== 'not_recommended' && (
              <OperatorCta
                module="comparison-table"
                tracker="main"
                operator={item?.relation}
                translationsObj={{
                  active: { translationKey: ctaKey, defaultValue: 'Visit' },
                  not_recommended: {
                    translationKey: 'not_recommended',
                    defaultValue: 'Not Recommended',
                  },
                  coming_soon: { translationKey: 'coming_soon', defaultValue: 'Soon Available' },
                  inactive: {
                    translationKey: 'inactive',
                    defaultValue: 'Not Accepting New Players',
                  },
                  blacklisted: { translationKey: 'blacklisted', defaultValue: 'Blacklisted' },
                }}
                // new key
                gtmClass="comparison-table-gtm btn-cta"
                pageTemplate={tempate}
              />
            )}
          </td>
        );
      default:
        return null;
    }
  };

  const table = () => {
    const row = [];
    tabelInfo.forEach((heading) => {
      const cells = [];

      items?.forEach((item, index) => {
        cells.push(cell(heading.key, item, `${heading.key}-${index}`, index));
      });

      row.push(
        <tr
          key={heading.key}
          className={`${styles[heading.key] || 'row'}_tr ${items?.length === 3 && styles.threeRow}`}
        >
          {/* <th>{translate(translations, heading.key, heading.defaultValue)}</th> */}
          {cells}
        </tr>
      );
    });

    return (
      <table className={styles.table}>
        <tbody>{row}</tbody>
      </table>
    );
  };

  return table();
}

ComparisonTable.propTypes = {
  items: PropTypes.arrayOf(PropTypes.object),
};

==> gatsby-sports-theme-1.0.37.tgz: package/src/components/atoms/cards/comparison-table/table/index.js <==
/* eslint-disable react/forbid-prop-types */
/* eslint-disable import/no-extraneous-dependencies */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/anchor-is-valid */
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { imagePrettyUrl, translate } from 'gatsby-core-theme/src/helpers/getters';
import LazyImg from 'gatsby-core-theme/src/hooks/lazy-image';
import OperatorCta from 'gatsby-core-theme/src/components/atoms/button/operator-cta';
import StarRating from 'gatsby-core-theme/src/components/molecules/star-rating/one-star';
import ReviewLink from 'gatsby-core-theme/src/components/atoms/review-link';
import Link from 'gatsby-core-theme/src/hooks/link';
import Bonus from 'gatsby-core-theme/src/components/molecules/bonus-box/template-one';
import GatsbyImg from 'gatsby-core-theme/src/hooks/gatsby-img';
import { Context } from 'gatsby-core-theme/src/context/MainProvider';

import LazyImage from '~hooks/lazy-image';
import verify from '../../../../../images/verify.svg';
import styles from './table.module.scss';

const listHeadings = [
  {
    id: 1,
    defaultValue: 'Casino name',
    key: 'casino_name',
  },
  {
    id: 2,
    defaultValue: 'Rating',
    key: 'rating',
  },
  {
    id: 3,
    defaultValue: 'Bonus',
    key: 'bonus',
    // customComponent: ({operator}) => ( <td>{operator.title}</td> ), This is an example
  },
  {
    id: 4,
    defaultValue: 'Top Features',
    key: 'top_features',
  },
  {
    id: 5,
    defaultValue: 'Banking',
    key: 'banking',
  },
  {
    id: 6,
    defaultValue: 'Payment Methods',
    key: 'payment_methods',
  },

  {
    id: 7,
    defaultValue: 'Currencies',
    key: 'currencies',
  },
  {
    id: 8,
    defaultValue: 'Licenses',
    key: 'licenses',
  },
  {
    id: 9,
    defaultValue: 'Cta',
    key: 'cta',
  },
];
export default function ComparisonTable({
  items,
  tabelInfo = listHeadings,
  ctaKey = 'play_now',
  type,
  tempate,
}) {
  const { translations } = useContext(Context) || {};

  const cell = (heading, item, key, index) => {
    const rowData = tabelInfo.find((m) => m.key === heading);
    if (rowData && rowData.customComponent) {
      const CustomComponent = rowData.customComponent;
      return <CustomComponent key={key} operator={item} />;
    }
    const imageObject =
      item?.relation?.standardised_logo_url_object || item?.relation?.logo_url_object;
    const itemName = item?.relation?.name;

    switch (heading) {
      case 'casino_name':
        return (
          <td key={key} className={styles.casinoName}>
            {imageObject?.filename ? (
              <LazyImg
                src={imagePrettyUrl(imageObject?.filename, 64, 64)}
                height={64}
                width={64}
                alt={itemName}
              />
            ) : (
              <GatsbyImg
                filename="default-operator.png"
                alt={itemName}
                width="9rem"
                height="9rem"
              />
            )}

            <span>{itemName}</span>
            {type === 'operator' && index === 0 ? null : (
              <ReviewLink
                template={tempate}
                {...(item?.relation?.name
                  ? { operatorName: item?.relation?.name }
                  : { pageName: item.title })}
                reviewPath={item.path}
              />
            )}
          </td>
        );
      case 'rating':
        return (
          <td key={key} className={styles.raiting}>
            <StarRating numOfStars={5} rating={item?.relation?.rating} />
            {item?.author?.image && (
              <div>
                <LazyImage
                  alt={item?.author?.image_alt}
                  src={imagePrettyUrl(item?.author?.image, 30, 30)}
                  width={30}
                  height={30}
                />
                <LazyImage src={verify} alt="verify" width={10} height={10} />
              </div>
            )}
          </td>
        );
      case 'bonus':
        return (
          <td key={key} className={styles.bonus}>
            <Bonus module="comparison_table" tracker="main" item={item?.relation} />
          </td>
        );
      case 'top_features':
        return (
          <td key={key} className={styles.topFeatures}>
            {item?.relation?.selling_points &&
              item?.relation?.selling_points.map((sellingPoint) => (
                <span key={sellingPoint}>
                  <svg
                    width="24"
                    height="24"
                    viewBox="0 0 24 24"
                    fill="none"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path
                      d="M18.7 7.1999C18.3 6.7999 17.7 6.7999 17.3 7.1999L9.8 14.6999L6.7 11.5999C6.3 11.1999 5.7 11.1999 5.3 11.5999C4.9 11.9999 4.9 12.5999 5.3 12.9999L9.1 16.7999C9.3 16.9999 9.5 17.0999 9.8 17.0999C10.1 17.0999 10.3 16.9999 10.5 16.7999L18.7 8.5999C19.1 8.1999 19.1 7.5999 18.7 7.1999Z"
                      fill="#FFDB20"
                    />
                  </svg>

                  {sellingPoint}
                </span>
              ))}
          </td>
        );
      case 'payment_methods':
        return (
          <td key={key} className={styles.paymentMethods}>
            <div key={key}>
              {item?.relation?.bonus?.deposit_methods &&
                // eslint-disable-next-line array-callback-return
                item?.relation?.bonus?.deposit_methods?.slice(0, 3)?.map((deposit) => {
                  const logo =
                    deposit?.standardised_logo_filename_object?.filename ||
                    deposit?.standardised_logo_filename ||
                    deposit?.logo_filename;
                  if (!logo) return;
                  return (
                    <Link to={deposit?.path}>
                      <LazyImg
                        key={`${key}-${deposit.name}`}
                        src={imagePrettyUrl(logo, 44, 29)}
                        // width={44}
                        // height={29}
                        alt={deposit.name}
                      />
                    </Link>
                  );
                })}
            </div>
            {item?.relation?.bonus?.deposit_methods &&
              item?.relation?.bonus?.deposit_methods.length > 3 && (
                <span>
                  {item?.relation?.bonus?.deposit_methods.length}{' '}
                  {translate(translations, 'comparison_more', 'More')}
                </span>
              )}
          </td>
        );
      case 'banking':
        return (
          <td key={key} className={styles.banking}>
            {item?.relation?.bonus?.min_deposit && <span>{item.relation.bonus.min_deposit}</span>}
          </td>
        );
      case 'currencies':
        return (
          <td key={key} className={styles.currencies}>
            {item?.relation?.bonus?.currencies &&
              // eslint-disable-next-line no-shadow
              item?.relation?.bonus?.currencies.slice(0, 6).map((currencies, index, array) => (
                // eslint-disable-next-line react/no-array-index-key
                <span key={`${key}-${currencies.iso_code}`}>
                  {currencies.iso_code}
                  {index < array.length - 1 ? ', ' : ' '}
                </span>
              ))}
          </td>
        );
      case 'licenses':
        return (
          <td key={key} className={styles.licenses}>
            {item?.relation?.bonus?.license_objects &&
              item?.relation?.bonus?.license_objects.slice(0, 3).map((license) => {
                if (license?.logo_filename) {
                  return (
                    <LazyImg
                      key={license.name}
                      src={imagePrettyUrl(license?.logo_filename, 72, 72)}
                      height={32}
                      width={72}
                      alt={license.name}
                    />
                  );
                }
                return <></>;
              })}
          </td>
        );
      case 'cta':
        return (
          <td key={key} className={styles.cta}>
            {item?.relation?.status !== 'not_recommended' && (
              <OperatorCta
                module="comparison-table"
                tracker="main"
                operator={item?.relation}
                translationsObj={{
                  active: { translationKey: ctaKey, defaultValue: 'Visit' },
                  not_recommended: {
                    translationKey: 'not_recommended',
                    defaultValue: 'Not Recommended',
                  },
                  coming_soon: { translationKey: 'coming_soon', defaultValue: 'Soon Available' },
                  inactive: {
                    translationKey: 'inactive',
                    defaultValue: 'Not Accepting New Players',
                  },
                  blacklisted: { translationKey: 'blacklisted', defaultValue: 'Blacklisted' },
                }}
                // new key
                gtmClass="comparison-table-gtm btn-cta"
                pageTemplate={tempate}
              />
            )}
          </td>
        );
      default:
        return null;
    }
  };

  const table = () => {
    const row = [];
    tabelInfo.forEach((heading) => {
      const cells = [];

      items?.forEach((item, index) => {
        cells.push(cell(heading.key, item, `${heading.key}-${index}`, index));
      });

      row.push(
        <tr
          key={heading.key}
          className={`${styles[heading.key] || 'row'}_tr ${items?.length === 3 && styles.threeRow}`}
        >
          {/* <th>{translate(translations, heading.key, heading.defaultValue)}</th> */}
          {cells}
        </tr>
      );
    });

    return (
      <table className={styles.table}>
        <tbody>{row}</tbody>
      </table>
    );
  };

  return table();
}

ComparisonTable.propTypes = {
  items: PropTypes.arrayOf(PropTypes.object),
};
